@@ -9,14 +9,14 @@ use warnings;
 use vars qw(@ISA @EXPORT @EXPORT_OK);
 use Exporter 'import';
 
-# Exporting the implemented subroutine.
-our @EXPORT = qw(GetAccount);
-
 # Base class of this (tron_addr) module.
 our @ISA = qw(Exporter);
 
+# Exporting the implemented subroutine.
+our @EXPORT = qw(GetAccount);
+
 # Set the package version. 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 # Load the required Perl module.
 use File::Basename;
@@ -60,18 +60,12 @@ sub GetAccount {
     my $json_data = "{}"; 
     # Check if address is not empty.
     if ($address ne "") {
-        # Assemble the payload from the address.
+        # Create the payload from the address.
         $payload = "\{\"address\":\"$address\",\"visible\":\"$visible\"\}";
         # Get the content from the service url.
         ($content, undef, undef, undef) = HTTP_Request($SERVICE_URL, $METHOD, $payload);
         # Format the content for the output.
-        if ($outflag eq "RAW") {
-            # Use the content as it is. 
-            $json_data = $content;    
-        } else {
-            # Encode the content.
-            $json_data = encode($content);
-        };
+        $json_data = format_output($content, $outflag);
     };
     # Return the json data.
     return $json_data;
@@ -113,11 +107,12 @@ CryptoTron::GetAccount - Perl extension for use with the blockchain of the crypt
 The module requests the account information of an account from the Tron
 blockchain using the so-called FULL-NODE HTTP API from the Tron network.
 For HTTP requests the methods C<POST> or C<GET> used in general. For the
-method C<GetAccount> the used method is C<POST>. The switch visible can be
-set to True or False. If the switch is set to True a Base58 address is used.
-If the switch is set to False a Hex address is used. A request results in a
-response in JSON format. The module returns formated string JSON data as well
-as unformated raw JSON data. 
+method C<GetAccount> the used method is C<POST>. The switch 'visible' can
+be set to 'True' or 'False'. If the switch is set to 'True' a Base58 address
+is used. If the switch is set to 'False' a Hex address is used. A request
+of the service API results in a response in JSON format. The module returns
+formatted string JSON data as well as unformated raw JSON data based on the
+output format flag. 
 
 =head1 MODULE METHOD
 
@@ -139,8 +134,31 @@ Dr. Peter Netz, E<lt>ztenretep@cpan.orgE<gt>
 
 Copyright (C) 2022 by Dr. Peter Netz
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.30.0 or,
-at your option, any later version of Perl 5 you may have available.
+The MIT License
+ 
+Permission is hereby granted, free of charge, to any person
+obtaining a copy of this software and associated
+documentation files (the "Software"), to deal in the Software
+without restriction, including without limitation the rights to
+use, copy, modify, merge, publish, distribute, sublicense,
+and/or sell copies of the Software, and to permit persons to
+whom the Software is furnished to do so, subject to the
+following conditions:
+ 
+The above copyright notice and this permission notice shall
+be included in all copies or substantial portions of the
+Software.
+ 
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT
+WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
+INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+MERCHANTABILITY, FITNESS FOR A PARTICULAR
+PURPOSE AND NONINFRINGEMENT. IN NO EVENT
+SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
+LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+CONNECTION WITH THE SOFTWARE OR THE USE OR
+OTHER DEALINGS IN THE SOFTWARE.
 
 =cut
