@@ -9,19 +9,24 @@ use warnings;
 use vars qw(@ISA @EXPORT @EXPORT_OK);
 use Exporter 'import';
 
+# Base class of this (tron_addr) module.
+our @ISA = qw(Exporter);
+
 # Exporting the implemented subroutine.
 our @EXPORT = qw(
+    HTTP_Request
     encode
-    HTTP_Request encode
+    encode_data
+    format_output
     %SERVICES
     $API_URL
 );
 
-# Base class of this (tron_addr) module.
-our @ISA = qw(Exporter);
+# Set alias.
+*encode = \&encode_data;
 
 # Set the package version. 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 # Load the required Perl modules or packages.
 use JSON::PP;
@@ -34,33 +39,68 @@ our $API_URL = 'https://api.trongrid.io';
 # Define the hash with the services.
 our %SERVICES = (
     'GetNextMaintenanceTime' => ['/wallet/getnextmaintenancetime', 'GET'],
-    'GetAccountResource'     => ['/wallet/getaccountresource',     'POST'],
-    'GetAccount'             => ['/walletsolidity/getaccount',     'POST'],
-    'GetReward'              => ['/wallet/getReward',              'POST'],
     'BroadcastTransaction'   => ['/wallet/broadcasttransaction',   'POST'],
-    'WithdrawBalance'        => ['/wallet/withdrawbalance',        'POST'],
+    'FreezeBalance'          => ['/wallet/freezebalance',          'POST'],
+    'GetAccount'             => ['/walletsolidity/getaccount',     'POST'],
     'GetAccountBalance'      => ['/wallet/getaccountbalance',      'POST'],
     'GetAccountNet'          => ['/wallet/getaccountnet',          'POST'],
-    'GetAccountResource'     => ['/wallet/getaccountresource',     'POST']
+    'GetAccountResource'     => ['/wallet/getaccountresource',     'POST'],
+    'GetReward'              => ['/wallet/getReward',              'POST'],
+    'UnfreezeBalance'        => ['/wallet/unfreezebalance',        'POST'],
+    'WithdrawBalance'        => ['/wallet/withdrawbalance',        'POST']
 );
 
+# Configure a new JSON:PP object.
+our $indent_enable = "true";
+our $indent_spaces = 4;
+our $JSON;
+$JSON = 'JSON::PP'->new->pretty;
+$JSON = $JSON->indent($indent_enable);
+$JSON = $JSON->indent_length($indent_spaces);
+$JSON = $JSON->allow_unknown("true");
+$JSON = $JSON->allow_blessed("true");
+$JSON = $JSON->allow_singlequote("true");
+
 # ---------------------------------------------------------------------------- #
-# Function encode()                                                            #
+# Function format_output()                                                     #
+# ---------------------------------------------------------------------------- #
+sub format_output {
+    # Assign the subroutine arguments to the local variables.
+    my ($content, $outflag) = @_;
+    # Declare the return variable.
+    my $output;
+    # Format the content for the output.
+    if ($outflag eq "RAW") {
+        # Use the content as it is. 
+        $output = $content;
+    } else {
+        # Encode the content.
+        $output = encode_data($content);
+    };
+    # Return formatted output.
+    return $output;
+};
+# ---------------------------------------------------------------------------- #
+# Function encode_data()                                                       #
 #                                                                              #
 # Description:                                                                 # 
-# The subroutine is encoding the given content using the module JSON::PP.      #
+# At first glance, it is not obvious why the response should be decoded and    #
+# then encoded back again. However, if one assumes that the response can have  #
+# any structure, this procedure makes sense. Decoding creates a Perl data      #
+# structure from the response. Encoding then creates a formatted string from   #
+# the Perl data structure.                                                     #
 #                                                                              #
-# @argument $content  Response content  (scalar)                               #
-# @returns  $encoded  Encoded content   (scalar)                               #
+# @argument $content  Content from response      (scalar)                      #
+# @return   $encoded  Encoded formatted content  (scalar)                      #
 # ---------------------------------------------------------------------------- #
-sub encode {
-    # Assign the argument to the local variable.
+sub encode_data {
+    # Assign the subroutine argument to the local variable.
     my $content = $_[0];
-    # Set up the options for the Perl module.
-    my $json = 'JSON::PP'->new->pretty;
-    # Encode content of the response.
-    my $encoded = $json->encode($content);
-    # Return encoded and decoded data.
+    # Decode the content of the response using 'JSON:PP'.
+    my $decoded = $JSON->decode($content);
+    # Encode the content of the response using 'JSON:PP'.
+    my $encoded = $JSON->encode($decoded);
+    # Return the encoded formatted JSON content.
     return $encoded;
 };
 
@@ -69,7 +109,7 @@ sub encode {
 #                                                                              #
 # Description:                                                                 #
 # The subroutine is using the HTTP methods GET or POST to send a request to a  #
-# known servive url of the Full-Node HTTP API. On success a content in form of #
+# known servive url of the FULL-NODE HTTP API. On success a content in form of #
 # JSON data is returned.                                                       #
 #                                                                              #
 # @argument $service_url  Service url       (scalar)                           #
@@ -83,29 +123,28 @@ sub HTTP_Request {
     my $response = "";
     my $errcode = "";
     my $errmsg = "";
-    # Set the header for the request.
-    my $header = [Accept => 'application/json',
-                  Content_Type => 'application/json'];
     # Create a new uri object from the service url.
     my $uri = URI->new($service_url);
     # Create a new user agent object.
-    my $ua = LWP::UserAgent->new;
+    my $ua = LWP::UserAgent->new();
+    # Set the default header of the request.
+    $ua->default_header('Accept' => 'application/json');
+    $ua->default_header('Content_Type' => 'application/json');
     # Get the response from the uri based on the given HTTP method.
     if ($method eq 'POST') {
-        $response = $ua->post($uri, $header, Content => $payload);
+        $response = $ua->post($uri, 'Content' => $payload);
     } elsif ($method eq 'GET') {
-        $response = $ua->get($uri, $header, Content => $payload);
+        $response = $ua->get($uri, 'Content' => $payload);
     };
+    # Get error code and error message.
+    $errcode = $response->code;
+    $errmsg = $response->message;
     # Check success of operation.
     if ($response->is_success) {
         # Get the content from the response.
         $content = $response->content;
-        $errcode = $response->code;
-        $errmsg = $response->message;
     } else {
-        # Get error code and error message.
-        $errcode = $response->code;
-        $errmsg = $response->message;
+        # Set the content to an empty string.
         $content = "";
     };
     # Return content, error code, error message and service url.
@@ -148,8 +187,31 @@ Dr. Peter Netz, E<lt>ztenretep@cpan.orgE<gt>
 
 Copyright (C) 2022 by Dr. Peter Netz
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.30.0 or,
-at your option, any later version of Perl 5 you may have available.
+The MIT License
+ 
+Permission is hereby granted, free of charge, to any person
+obtaining a copy of this software and associated
+documentation files (the "Software"), to deal in the Software
+without restriction, including without limitation the rights to
+use, copy, modify, merge, publish, distribute, sublicense,
+and/or sell copies of the Software, and to permit persons to
+whom the Software is furnished to do so, subject to the
+following conditions:
+ 
+The above copyright notice and this permission notice shall
+be included in all copies or substantial portions of the
+Software.
+ 
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT
+WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
+INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+MERCHANTABILITY, FITNESS FOR A PARTICULAR
+PURPOSE AND NONINFRINGEMENT. IN NO EVENT
+SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
+LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+CONNECTION WITH THE SOFTWARE OR THE USE OR
+OTHER DEALINGS IN THE SOFTWARE.
 
 =cut
