@@ -16,7 +16,7 @@ our @EXPORT = qw(WithdrawBalance);
 our @ISA = qw(Exporter);
 
 # Set the package version. 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # Load the required Perl modules or packages.
 use URI;
@@ -139,8 +139,31 @@ Dr. Peter Netz, E<lt>ztenretep@cpan.orgE<gt>
 
 Copyright (C) 2022 by Dr. Peter Netz
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.30.0 or,
-at your option, any later version of Perl 5 you may have available.
+The MIT License
+ 
+Permission is hereby granted, free of charge, to any person
+obtaining a copy of this software and associated
+documentation files (the "Software"), to deal in the Software
+without restriction, including without limitation the rights to
+use, copy, modify, merge, publish, distribute, sublicense,
+and/or sell copies of the Software, and to permit persons to
+whom the Software is furnished to do so, subject to the
+following conditions:
+ 
+The above copyright notice and this permission notice shall
+be included in all copies or substantial portions of the
+Software.
+ 
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT
+WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
+INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+MERCHANTABILITY, FITNESS FOR A PARTICULAR
+PURPOSE AND NONINFRINGEMENT. IN NO EVENT
+SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
+LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+CONNECTION WITH THE SOFTWARE OR THE USE OR
+OTHER DEALINGS IN THE SOFTWARE.
 
 =cut
